summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/tools/designer/uic/uic.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/tools/designer/uic/uic.cpp
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/tools/designer/uic/uic.cpp')
-rw-r--r--tqtinterface/qt4/tools/designer/uic/uic.cpp40
1 files changed, 20 insertions, 20 deletions
diff --git a/tqtinterface/qt4/tools/designer/uic/uic.cpp b/tqtinterface/qt4/tools/designer/uic/uic.cpp
index 5eed175..7a71eaf 100644
--- a/tqtinterface/qt4/tools/designer/uic/uic.cpp
+++ b/tqtinterface/qt4/tools/designer/uic/uic.cpp
@@ -77,10 +77,10 @@ TQString Uic::fixString( const TQString &str, bool encode )
TQString s;
if ( !encode ) {
s = str;
- s.tqreplace( "\\", "\\\\" );
- s.tqreplace( "\"", "\\\"" );
- s.tqreplace( "\r", "" );
- s.tqreplace( "\n", "\\n\"\n\"" );
+ s.replace( "\\", "\\\\" );
+ s.replace( "\"", "\\\"" );
+ s.replace( "\r", "" );
+ s.replace( "\n", "\\n\"\n\"" );
} else {
TQCString utf8 = str.utf8();
const int l = utf8.length();
@@ -236,7 +236,7 @@ TQString Uic::getFormClassName( const TQDomElement& e )
if ( n.tagName() == "class" ) {
TQString s = n.firstChild().toText().data();
int i;
- while ( ( i = s.tqfind(' ' )) != -1 )
+ while ( ( i = s.find(' ' )) != -1 )
s[i] = '_';
cn = s;
}
@@ -315,7 +315,7 @@ TQString Uic::getDatabaseInfo( const TQDomElement& e, const TQString& tag )
return TQString();
n = getObjectProperty( e, "database" );
if ( n.firstChild().toElement().tagName() == "stringlist" ) {
// tqfind correct stringlist entry
TQDomElement n1 = n.firstChild().firstChild().toElement();
for ( int i = 0; i < child && !n1.isNull(); ++i )
n1 = n1.nextSibling().toElement();
@@ -329,7 +329,7 @@ TQString Uic::getDatabaseInfo( const TQDomElement& e, const TQString& tag )
void Uic::registerLayouts( const TQDomElement &e )
{
- if ( layouts.tqcontains(e.tagName())) {
+ if ( layouts.contains(e.tagName())) {
createObjectDecl(e);
TQString t = e.tagName();
if ( t == "vbox" || t == "hbox" || t == "grid" )
@@ -512,10 +512,10 @@ void Uic::createMenuBarImpl( const TQDomElement &n, const TQString &parentClass,
out << indent << itemName << " = new TQPopupMenu( this );" << endl;
createPopupMenuImpl( c, parentClass, itemName );
out << indent << objName << "->insertItem( TQString(\"\"), " << itemName << ", " << i << " );" << endl;
- TQString tqfindItem(objName + "->tqfindItem(%1)");
- tqfindItem = tqfindItem.arg(i);
- trout << indent << "if (" << tqfindItem << ")" << endl;
- trout << indent << indent << tqfindItem << "->setText( " << trcall( c.attribute( "text" ) ) << " );" << endl;
+ TQString findItem(objName + "->findItem(%1)");
+ findItem = findItem.arg(i);
+ trout << indent << "if (" << findItem << ")" << endl;
+ trout << indent << indent << findItem << "->setText( " << trcall( c.attribute( "text" ) ) << " );" << endl;
} else if ( c.tagName() == "separator" ) {
out << endl;
out << indent << objName << "->insertSeparator( " << i << " );" << endl;
@@ -854,7 +854,7 @@ TQString Uic::createLayoutImpl( const TQDomElement &e, const TQString& parentCla
if ( n.tagName() == "spacer" ) {
TQString child = createSpacerImpl( n, parentClass, tqparent, objName );
out << indent << objName << "->addItem( static_cast<TQLayoutItem*>(static_cast<QLayoutItem*>( " << child << " )) );" << endl;
- } else if ( tags.tqcontains( n.tagName() ) ) {
+ } else if ( tags.contains( n.tagName() ) ) {
TQString child = createObjectImpl( n, parentClass, tqparent, objName );
if ( isLayout( child ) )
out << indent << objName << "->addLayout( static_cast<TQLayout*>(static_cast<QLayout*>( " << child << " )) );" << endl;
@@ -881,7 +881,7 @@ TQString Uic::createLayoutImpl( const TQDomElement &e, const TQString& parentCla
else
out << indent << objName << "->addItem( " << child << ", "
<< row << ", " << col << " );" << endl;
- } else if ( tags.tqcontains( n.tagName() ) ) {
+ } else if ( tags.contains( n.tagName() ) ) {
TQString child = createObjectImpl( n, parentClass, tqparent, objName );
out << endl;
TQString o = "Widget";
@@ -1052,13 +1052,13 @@ TQString Uic::registerObject( const TQString& name )
TQString result = name;
int i;
- while ( ( i = result.tqfind(' ' )) != -1 ) {
+ while ( ( i = result.find(' ' )) != -1 ) {
result[i] = '_';
}
- if ( objectNames.tqcontains( result ) ) {
+ if ( objectNames.contains( result ) ) {
int i = 2;
- while ( objectNames.tqcontains( result + "_" + TQString::number(i) ) )
+ while ( objectNames.contains( result + "_" + TQString::number(i) ) )
i++;
result += "_";
result += TQString::number(i);
@@ -1076,7 +1076,7 @@ TQString Uic::registerObject( const TQString& name )
*/
TQString Uic::registeredName( const TQString& name )
{
- if ( !objectMapper.tqcontains( name ) )
+ if ( !objectMapper.contains( name ) )
return name;
return objectMapper[name];
}
@@ -1086,7 +1086,7 @@ TQString Uic::registeredName( const TQString& name )
*/
bool Uic::isObjectRegistered( const TQString& name )
{
- return objectMapper.tqcontains( name );
+ return objectMapper.contains( name );
}
@@ -1100,7 +1100,7 @@ TQStringList Uic::unique( const TQStringList& list )
TQStringList result;
for ( TQStringList::ConstIterator it = list.begin(); it != list.end(); ++it ) {
- if ( !result.tqcontains(*it) )
+ if ( !result.contains(*it) )
result += *it;
}
return result;
@@ -1122,7 +1122,7 @@ TQString Uic::createObjectInstance( const TQString& objClass, const TQString& tq
bool Uic::isLayout( const TQString& name ) const
{
- return layoutObjects.tqcontains( name );
+ return layoutObjects.contains( name );
}
@@ -315,7 +315,7 @@ TQString Uic::getDatabaseInfo( const TQDomElement& e, const TQString& tag )
n = getObjectProperty( e, "database" );
if ( n.firstChild().toElement().tagName() == "stringlist" ) {
- // tqfind correct stringlist entry
+ // find correct stringlist entry
TQDomElement n1 = n.firstChild().firstChild().toElement();
for ( int i = 0; i < child && !n1.isNull(); ++i )